Divmod Epsilon
==============
.. image:: https://github.com/twisted/epsilon/workflows/Python%20package/badge.svg
    :target: https://travis-ci.org/twisted/epsilon
.. image:: https://img.shields.io/pypi/v/Epsilon
    :alt: PyPI

Epsilon is a set of utility modules, commonly used by all Divmod projects.

This is intended mainly as a support package for code used by Divmod projects,
and not as an external library.  However, it contains many useful modules and
you can feel free to use them!
